@@ -24,13 +24,15 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-kinesisfirehose-s3-and-kinesisanalytics`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.kinesisfirehoses3kinesisanalytics`|
 
+## Overview
+
 This AWS Solutions Construct implements an Amazon Kinesis Firehose delivery stream connected to an Amazon S3 bucket, and an Amazon Kinesis Analytics application.
 
 Here is a minimal deployable pattern definition:
 
 Typescript
 
-```javascript
+```python
 import { Construct } from 'constructs';
 import { Stack, StackProps } from 'aws-cdk-lib';
 import { KinesisFirehoseToAnalyticsAndS3 } from '@aws-solutions-constructs/aws-kinesisfirehose-s3-and-kinesisanalytics';
@@ -212,7 +214,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -224,6 +226,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_iam
@@ -248,12 +252,12 @@ class KinesisFirehoseToAnalyticsAndS3(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        kinesis_analytics_props: typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps] = None,
+        kinesis_analytics_props: typing.Optional[typing.Union[aws_cdk.aws_kinesisanalytics.CfnApplicationProps, typing.Dict[str, typing.Any]]] = None,
         kinesis_firehose_props: typing.Any = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -271,6 +275,10 @@ class KinesisFirehoseToAnalyticsAndS3(
         :since: 0.8.0
         :summary: Constructs a new instance of the KinesisFirehoseToAnalyticsAndS3 class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisFirehoseToAnalyticsAndS3.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisFirehoseToAnalyticsAndS3Props(
             bucket_props=bucket_props,
             existing_bucket_obj=existing_bucket_obj,
@@ -336,12 +344,12 @@ class KinesisFirehoseToAnalyticsAndS3Props:
     def __init__(
         self,
         *,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        kinesis_analytics_props: typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps] = None,
+        kinesis_analytics_props: typing.Optional[typing.Union[aws_cdk.aws_kinesisanalytics.CfnApplicationProps, typing.Dict[str, typing.Any]]] = None,
         kinesis_firehose_props: typing.Any = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''The properties for the KinesisFirehoseToAnalyticsAndS3 class.
@@ -362,6 +370,15 @@ class KinesisFirehoseToAnalyticsAndS3Props:
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisFirehoseToAnalyticsAndS3Props.__init__)
+            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
+            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
+            check_type(argname="argument kinesis_analytics_props", value=kinesis_analytics_props, expected_type=type_hints["kinesis_analytics_props"])
+            check_type(argname="argument kinesis_firehose_props", value=kinesis_firehose_props, expected_type=type_hints["kinesis_firehose_props"])
+            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
